==> haskell-io-streams-haproxy-1.0.1.0-374-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-DG9Ya69eNnB8sdEkgC9mD1
key:                  io-streams-haproxy-1.0.1.0-DG9Ya69eNnB8sdEkgC9mD1
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  19e83e8cb86fe91b022ebe757d27aacf
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-DG9Ya69eNnB8sdEkgC9mD1
depends:
    attoparsec-0.14.4-LQtEgQtiyVz1VW0BNcPBCE base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-K3ZQmONHmVa7oeadrtOqSo
    network-3.1.4.0-IC0hdE8eZqJ6PeeNglfLy3 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.1.0-375-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-JOmIjMgUhceCFcYnW2mZhz
key:                  io-streams-haproxy-1.0.1.0-JOmIjMgUhceCFcYnW2mZhz
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  6d3cdd3993bdd58213affaec12bfb1e4
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-JOmIjMgUhceCFcYnW2mZhz
depends:
    attoparsec-0.14.4-1LkqTl6pHdPB5xyeiPPJjY base-4.17.2.1
    bytestring-0.11.5.3 io-streams-1.5.2.2-B0DWqZ9olXuFkqoIZx9Wbq
    network-3.1.4.0-Fdysxcu9OH32QGRZPBFSYA transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
